Monte Carlo random number generator
***********************************

.. autoclass:: stats_arrays.MCRandomNumberGenerator
    :members:

    .. automethod:: stats_arrays.MCRandomNumberGenerator.__init__
